Changes
=======

Unreleased
----------

Version 1.7.4
-------------

Released 2023-09-09

- Update dependencies.
    - Bump cryptography to 41.0.3. `#293 <https://github.com/dajiaji/pyseto/pull/293>`__
- Update dev dependencies.
    - Bump tox to 4.11.2. `#309 <https://github.com/dajiaji/pyseto/pull/309>`__
    - Bump pytest to 7.4.2. `#308 <https://github.com/dajiaji/pyseto/pull/308>`__
    - Bump pre-commit to 3.4.0. `#306 <https://github.com/dajiaji/pyseto/pull/306>`__
    - Bump sphinx-autodoc-typehints to 1.24.0. `#303 <https://github.com/dajiaji/pyseto/pull/303>`__
    - Bump sphinx to 7.1.2. `#302 <https://github.com/dajiaji/pyseto/pull/302>`__
    - Bump certifi to 2023.7.22. `#301 <https://github.com/dajiaji/pyseto/pull/301>`__
    - Bump sphinx-rtd-theme to 1.3.0. `#299 <https://github.com/dajiaji/pyseto/pull/299>`__
    - Bump pre-commit/black-docs to 1.16.0. `#298 <https://github.com/dajiaji/pyseto/pull/298>`__
    - Bump pre-commit/mirrors-mypy to 1.5.1. `#298 <https://github.com/dajiaji/pyseto/pull/298>`__
    - Bump pre-commit/flake8 to 6.1.0. `#292 <https://github.com/dajiaji/pyseto/pull/292>`__
    - Bump pre-commit/black to 23.7.0. `#290 <https://github.com/dajiaji/pyseto/pull/290>`__

Version 1.7.3
-------------

Released 2023-07-03

- Drop support for Python 3.7. `#285 <https://github.com/dajiaji/pyseto/pull/285>`__
- Update dependencies.
    - Bump cryptography to 41.0.1. `#286 <https://github.com/dajiaji/pyseto/pull/286>`__
    - Bump iso8601 to 2.0.0. `#277 <https://github.com/dajiaji/pyseto/pull/277>`__
    - Bump pycryptodomex to 3.18.0. `#268 <https://github.com/dajiaji/pyseto/pull/268>`__
- Update dev dependencies.
    - Bump pre-commit/mirrors-mypy to 1.4.1. `#282 <https://github.com/dajiaji/pyseto/pull/282>`__
    - Bump pytest to 7.4.0. `#281 <https://github.com/dajiaji/pyseto/pull/281>`__
    - Bump tox to 4.6.3. `#280 <https://github.com/dajiaji/pyseto/pull/280>`__
    - Bump pre-commit/black-docs to 1.14.0. `#279 <https://github.com/dajiaji/pyseto/pull/279>`__
    - Bump sphinx-rtd-theme to 1.2.2. `#276 <https://github.com/dajiaji/pyseto/pull/276>`__
    - Bump pytest-cov to 4.1.0. `#272 <https://github.com/dajiaji/pyseto/pull/272>`__

Version 1.7.2
-------------

Released 2023-04-23

- Update SECURITY.md. `#245 <https://github.com/dajiaji/pyseto/pull/245>`__
- Add SECURITY.md. `#244 <https://github.com/dajiaji/pyseto/pull/244>`__
- Fix CHANGES. `#233 <https://github.com/dajiaji/pyseto/pull/233>`__
- Update dependencies.
    - Bump cryptography to 40.0.2. `#262 <https://github.com/dajiaji/pyseto/pull/262>`__
- Update dev dependencies.
    - Bump pytest to 7.3.1. `#263 <https://github.com/dajiaji/pyseto/pull/263>`__
    - Bump tox to 4.4.12. `#261 <https://github.com/dajiaji/pyseto/pull/261>`__
    - Bump pre-commit/mirrors-mypy to 1.2.0. `#260 <https://github.com/dajiaji/pyseto/pull/260>`__
    - Bump pre-commit/black to 23.3.0. `#256 <https://github.com/dajiaji/pyseto/pull/256>`__
    - Bump sphinx-rtd-theme to 1.2.0. `#243 <https://github.com/dajiaji/pyseto/pull/243>`__
    - Bump pre-commit/black to 23.1.0. `#240 <https://github.com/dajiaji/pyseto/pull/240>`__
    - Bump pre-commit/isort to 5.12.0. `#237 <https://github.com/dajiaji/pyseto/pull/237>`__

Version 1.7.1
-------------

Released 2023-01-21

- Use allowlist_externals on tox. `#208 <https://github.com/dajiaji/pyseto/pull/208>`__

- Update dependencies.
    - Bump cryptography to 39.0.0. `#212 <https://github.com/dajiaji/pyseto/pull/212>`__
- Update dev dependencies.
    - Bump tox to 4.3.5. `#230 <https://github.com/dajiaji/pyseto/pull/230>`__
    - Bump pre-commit/black-docs to 1.13.0. `#227 <https://github.com/dajiaji/pyseto/pull/227>`__
    - Bump pre-commit/isort to 5.11.4. `#227 <https://github.com/dajiaji/pyseto/pull/227>`__
    - Bump sphinx-autodoc-typehints to 1.21.0. `#226 <https://github.com/dajiaji/pyseto/pull/226>`__
    - Bump pytest to 7.2.1. `#225 <https://github.com/dajiaji/pyseto/pull/225>`__
    - Bump pre-commit to 2.20.0. `#200 <https://github.com/dajiaji/pyseto/pull/200>`__

Version 1.7.0
-------------

Released 2022-12-17

- Drop support for Python 3.6. `#196 <https://github.com/dajiaji/pyseto/pull/196>`__
- Add CI for Python 11. `#191 <https://github.com/dajiaji/pyseto/pull/191>`__
- Fix typo on PASETO usage document. `#183 <https://github.com/dajiaji/pyseto/pull/183>`__

- Update dependencies.
    - Bump pycryptodomex to 3.16.0. `#195 <https://github.com/dajiaji/pyseto/pull/195>`__
    - Bump cryptography to 38.0.4. `#195 <https://github.com/dajiaji/pyseto/pull/195>`__
- Update dev dependencies.
    - Bump pytest to 7.2.0. `#195 <https://github.com/dajiaji/pyseto/pull/195>`__
    - Bump pre-commit/isort to 5.11.1. `#193 <https://github.com/dajiaji/pyseto/pull/193>`__
    - Bump pre-commit/black to 22.12.0. `#193 <https://github.com/dajiaji/pyseto/pull/193>`__
    - Bump pre-commit/pre-commit-hooks to 4.4.0. `#190 <https://github.com/dajiaji/pyseto/pull/190>`__
    - Bump pre-commit/flake8 to 6.0.0. `#190 <https://github.com/dajiaji/pyseto/pull/190>`__
    - Bump pre-commit/mirrors-mypy to 0.991. `#187 <https://github.com/dajiaji/pyseto/pull/187>`__
    - Bump tox to 3.27.1. `#185 <https://github.com/dajiaji/pyseto/pull/185>`__
    - Bump sphinx-rtd-theme to 1.1.1. `#184 <https://github.com/dajiaji/pyseto/pull/184>`__

Version 1.6.12
--------------

Released 2022-11-03

- Update dependencies.
    - Bump cryptography to 38.0.3. `#180 <https://github.com/dajiaji/pyseto/pull/180>`__
- Update dev dependencies.
    - Bump sphinx-rtd-theme to 1.1.0. `#179 <https://github.com/dajiaji/pyseto/pull/179>`__
    - Bump tox to 3.27.0. `#178 <https://github.com/dajiaji/pyseto/pull/178>`__
    - Bump sphinx to 5.3.0. `#177 <https://github.com/dajiaji/pyseto/pull/177>`__
    - Bump pre-commit/mirrors-mypy to 0.982. `#176 <https://github.com/dajiaji/pyseto/pull/176>`__
    - Bump pre-commit/black to 22.10.0. `#176 <https://github.com/dajiaji/pyseto/pull/176>`__

Version 1.6.11
--------------

Released 2022-10-08

- Update dependencies.
    - Bump iso8601 to 1.1.0. `#171 <https://github.com/dajiaji/pyseto/pull/171>`__
    - Bump cryptography to 38.0.1. `#167 <https://github.com/dajiaji/pyseto/pull/167>`__
- Update dev dependencies.
    - Bump pre-commit/mirrors-mypy to 0.981. `#174 <https://github.com/dajiaji/pyseto/pull/174>`__
    - Bump sphinx to 5.2.3. `#173 <https://github.com/dajiaji/pyseto/pull/173>`__
    - Bump pytest-cov to 4.0.0. `#172 <https://github.com/dajiaji/pyseto/pull/172>`__
    - Bump tox to 3.26.0. `#168 <https://github.com/dajiaji/pyseto/pull/168>`__
    - Bump pre-commit/black to 22.8.0. `#166 <https://github.com/dajiaji/pyseto/pull/166>`__
    - Bump freezegun to 1.2.2. `#165 <https://github.com/dajiaji/pyseto/pull/165>`__

Version 1.6.10
--------------

Released 2022-08-10

- Update dependencies.
    - Bump cryptography to 37.0.4. `#157 <https://github.com/dajiaji/pyseto/pull/157>`__
    - Bump pycryptodomex to 3.15.0. `#153 <https://github.com/dajiaji/pyseto/pull/153>`__
- Update dev dependencies.
    - Bump pre-commit/flake8 to 5.0.4. `#162 <https://github.com/dajiaji/pyseto/pull/162>`__
    - Bump sphinx to 5.1.1. `#160 <https://github.com/dajiaji/pyseto/pull/160>`__
    - Bump pre-commit/mirrors-mypy to 0.971. `#159 <https://github.com/dajiaji/pyseto/pull/159>`__
    - Bump pre-commit/black to 22.6.0. `#156 <https://github.com/dajiaji/pyseto/pull/156>`__
    - Bump tox to 3.25.1. `#155 <https://github.com/dajiaji/pyseto/pull/155>`__
- Drop support for Python3.6. `#154 <https://github.com/dajiaji/pyseto/pull/154>`__

Version 1.6.9
-------------

Released 2022-06-18

- Update dependencies.
    - Bump cryptography to 37.0.2. `#146 <https://github.com/dajiaji/pyseto/pull/146>`__
- Update dev dependencies.
    - Bump sphinx to 5.0.2. `#151 <https://github.com/dajiaji/pyseto/pull/151>`__
    - Bump pre-commit/mirrors-mypy to 0.961. `#150 <https://github.com/dajiaji/pyseto/pull/150>`__
    - Bump pre-commit/pre-commit-hooks to 4.3.0. `#150 <https://github.com/dajiaji/pyseto/pull/150>`__

Version 1.6.8
-------------

Released 2022-05-01

- Compare MACs in constant time. `#143 <https://github.com/dajiaji/pyseto/pull/143>`__
- Refine pyproject to add tool.poetry.extras. `#138 <https://github.com/dajiaji/pyseto/pull/138>`__
- Update dependencies.
    - Bump cryptography to 37.0.1. `#142 <https://github.com/dajiaji/pyseto/pull/142>`__
- Update dev dependencies.
    - Bump pre-commit/pre-commit-hooks from 4.1.0 to 4.2.0. `#140 <https://github.com/dajiaji/pyseto/pull/140>`__
    - Bump tox from 3.24.5 to 3.25.0. `#139 <https://github.com/dajiaji/pyseto/pull/139>`__

Version 1.6.7
-------------

Released 2022-04-03

- Update dependencies.
    - Bump cryptography from 36.0.1 to 36.0.2. `#132 <https://github.com/dajiaji/pyseto/pull/132>`__
- Update dependencies.
    - Bump sphinx from 4.4.0 to 4.5.0. `#135 <https://github.com/dajiaji/pyseto/pull/135>`__
    - Bump freezegun from 1.1.0 to 1.2.1. `#133 <https://github.com/dajiaji/pyseto/pull/133>`__
    - Bump pre-commit/mirrors-mypy from 0.931 to 0.940. `#131 <https://github.com/dajiaji/pyseto/pull/131>`__

Version 1.6.6
-------------

Released 2022-03-01

- Fix bug on to_peer_paserk_id for v1/2 local key. `#128 <https://github.com/dajiaji/pyseto/pull/128>`__
- Add support for to_peer_paserk_id on v1/v3. `#128 <https://github.com/dajiaji/pyseto/pull/128>`__

Version 1.6.5
-------------

Released 2022-01-20

- Avoid re-encoding/decoding output from serializer. `#118 <https://github.com/dajiaji/pyseto/pull/118>`__

Version 1.6.4
-------------

Released 2022-01-14

- Fix bug on deserializing payload in local paseto. `#114 <https://github.com/dajiaji/pyseto/pull/114>`__

Version 1.6.3
-------------

Released 2022-01-03

- Add optional flag to docs dependencies. `#109 <https://github.com/dajiaji/pyseto/pull/109>`__
- Remove tool.poetry.extra from pyproject.toml. `#109 <https://github.com/dajiaji/pyseto/pull/109>`__
- Add pre-commit hooks for checking json, toml and yaml files. `#108 <https://github.com/dajiaji/pyseto/pull/108>`__

Version 1.6.2
-------------

Released 2022-01-02

- Introduce freezegun for test. `#106 <https://github.com/dajiaji/pyseto/pull/106>`__
- Add 2022 to copyright and license. `#105 <https://github.com/dajiaji/pyseto/pull/105>`__
- Add license information to PyPI. `#104 <https://github.com/dajiaji/pyseto/pull/104>`__

Version 1.6.1
-------------

Released 2021-12-31

- Refine github actions. `#99 <https://github.com/dajiaji/pyseto/pull/99>`__
- Use pytest-cov instead of coverage. `#98 <https://github.com/dajiaji/pyseto/pull/98>`__
- Refine pyproject.toml. `#97 <https://github.com/dajiaji/pyseto/pull/97>`__
- Refine tox.ini. `#96 <https://github.com/dajiaji/pyseto/pull/96>`__
- Update pytest requirement form ^5.2 to ^6.2. `#91 <https://github.com/dajiaji/pyseto/pull/91>`__

Version 1.6.0
-------------

Released 2021-12-11

- Migrate to poetry. `#89 <https://github.com/dajiaji/pyseto/pull/89>`__
- Update max line length to 128. `#89 <https://github.com/dajiaji/pyseto/pull/89>`__

Version 1.5.0
-------------

Released 2021-11-24

- Add support for aud verification. `#86 <https://github.com/dajiaji/pyseto/pull/86>`__
- Add to_peer_paserk_id to KeyInterface. `#85 <https://github.com/dajiaji/pyseto/pull/85>`__

Version 1.4.0
-------------

Released 2021-11-22

- Add is_secret to KeyInterface. `#82 <https://github.com/dajiaji/pyseto/pull/82>`__
- Disclose KeyInterface class. `#81 <https://github.com/dajiaji/pyseto/pull/81>`__
- Disclose Token class. `#80 <https://github.com/dajiaji/pyseto/pull/80>`__

Version 1.3.0
-------------

Released 2021-11-20

- Add support for nbf validation. `#76 <https://github.com/dajiaji/pyseto/pull/76>`__
- Add support for dict typed footer. `#75 <https://github.com/dajiaji/pyseto/pull/75>`__
- Add leeway for exp validation. `#74 <https://github.com/dajiaji/pyseto/pull/74>`__
- Add Paseto class. `#72 <https://github.com/dajiaji/pyseto/pull/72>`__
- Add support for exp claim. `#71 <https://github.com/dajiaji/pyseto/pull/71>`__

Version 1.2.0
-------------

Released 2021-11-14

- Refine README (Add CONTRIBUTING, etc.). `#68 <https://github.com/dajiaji/pyseto/pull/68>`__
- Introduce serializer/deserializer for payload. `#67 <https://github.com/dajiaji/pyseto/pull/67>`__
- Sync official test vectors. `#64 <https://github.com/dajiaji/pyseto/pull/64>`__

Version 1.1.0
-------------

Released 2021-10-16

- Add support for Python 3.10. `#60 <https://github.com/dajiaji/pyseto/pull/60>`__
- Add support for k2.seal and k4.seal. `#57 <https://github.com/dajiaji/pyseto/pull/57>`__
- Add py.typed. `#56 <https://github.com/dajiaji/pyseto/pull/56>`__

Version 1.0.0
-------------

Released 2021-09-25

- [Breaking Change] Remove str support for version. `#53 <https://github.com/dajiaji/pyseto/pull/53>`__
- [Breaking Change] Rename type of Key.new to purpose. `#52 <https://github.com/dajiaji/pyseto/pull/52>`__
- Add support for PASERK password-based key wrapping. `#47 <https://github.com/dajiaji/pyseto/pull/47>`__
- Add support for PASERK key wrapping. `#46 <https://github.com/dajiaji/pyseto/pull/46>`__

Version 0.7.1
-------------

Released 2021-09-18

- Make PASERK secret for Ed25519 compliant with PASERK spec. `#44 <https://github.com/dajiaji/pyseto/pull/44>`__

Version 0.7.0
-------------

Released 2021-09-16

- Add from_paserk to Key. `#41 <https://github.com/dajiaji/pyseto/pull/41>`__
- Add support for paserk lid. `#40 <https://github.com/dajiaji/pyseto/pull/40>`__
- Add support for paserk local. `#40 <https://github.com/dajiaji/pyseto/pull/40>`__
- Add to_paserk_id to KeyInterface. `#39 <https://github.com/dajiaji/pyseto/pull/39>`__
- Add to_paserk to KeyInterface. `#38 <https://github.com/dajiaji/pyseto/pull/38>`__
- Fix public key compression for v3.

Version 0.6.1
-------------

Released 2021-09-12

- Add usage examples and related tests. `#36 <https://github.com/dajiaji/pyseto/pull/36>`__

Version 0.6.0
-------------

Released 2021-09-11

- Add tests for sample code. `#34 <https://github.com/dajiaji/pyseto/pull/34>`__
- Allow int type version for Key.new. `#33 <https://github.com/dajiaji/pyseto/pull/33>`__

Version 0.5.0
-------------

Released 2021-09-11

- Add API reference about Token. `#30 <https://github.com/dajiaji/pyseto/pull/30>`__
- Add support for multiple keys on decode. `#29 <https://github.com/dajiaji/pyseto/pull/29>`__

Version 0.4.0
-------------

Released 2021-09-10

- Add tests for public and fix error message. `#26 <https://github.com/dajiaji/pyseto/pull/26>`__
- Add tests for local and fix error message. `#25 <https://github.com/dajiaji/pyseto/pull/25>`__
- Add tests for Token. `#24 <https://github.com/dajiaji/pyseto/pull/24>`__
- Add tests for Key and fix checking argument. `#22 <https://github.com/dajiaji/pyseto/pull/22>`__
- Add docstrings for KeyInterface. `#21 <https://github.com/dajiaji/pyseto/pull/21>`__

Version 0.3.2
-------------

Released 2021-09-07

- Add API reference. `#17 <https://github.com/dajiaji/pyseto/pull/17>`__

Version 0.3.1
-------------

Released 2021-09-06

- Fix readthedocs build error. `#13 <https://github.com/dajiaji/pyseto/pull/13>`__

Version 0.3.0
-------------

Released 2021-09-06

- Add docs. `#10 <https://github.com/dajiaji/pyseto/pull/10>`__
- Add Key.from_asymmetric_key_params. `#8 <https://github.com/dajiaji/pyseto/pull/8>`__
- Make NotSupportedError public. `#8 <https://github.com/dajiaji/pyseto/pull/8>`__

Version 0.2.0
-------------

Released 2021-09-05

- Add Token object as a response of decode(). `#6 <https://github.com/dajiaji/pyseto/pull/6>`__

Version 0.1.0
-------------

Released 2021-09-05

- First public preview release.
